Re-exports
pub use self::event::Event;
Modules
- event
- This module contains the set of compiler-emitted event codes, and their explanations
Structs
- Debug
Executor - A special version of crate::Executor which provides finer-grained control over execution, and captures a ton of information about the program being executed, so as to make it possible to introspect everything about the program and the state of the VM at a given cycle.
- Debugger
Host - This is an implementation of Host which is essentially miden_processor::DefaultHost, but extended with additional functionality for debugging, in particular it manages trace events that record the entry or exit of a procedure call frame.
- Diagnostic
Executor - A [
ProgramExecutor] that wrapsFastProcessorwith diagnostic capabilities. - Event
Mutation Recorder - A shared, cloneable log of the advice mutations produced by event handlers.
- Execution
Config - Execution
Trace - An ExecutionTrace represents a final state of a program that was executed.
- Executor
- The Executor is responsible for executing a program with the Miden VM.
- Mast
Forest Recorder - A shared, cloneable log of the MAST forests a host resolved during execution.
- Replay
Snapshot - Everything needed to replay a recorded execution in the debugger.
- Replay
Snapshot Recorder - Shared status handle for a configured replay snapshot write.
- Replay
Snapshot Write - Successful replay snapshot write metadata.
- Replay
Snapshot Write Error - Error metadata for a failed replay snapshot write.
Enums
- Replay
Snapshot Error - Error reading a ReplaySnapshot from a file.
Traits
Functions
- clone_
advice_ mutation - Clone a single AdviceMutation.
- clone_
advice_ mutations - Clone a batch of AdviceMutations. See clone_advice_mutation.
- read_
advice_ mutation - Deserialize a single AdviceMutation from
source. - read_
event_ log - Deserialize a recorded event log from
source. - write_
advice_ mutation - Serialize a single AdviceMutation into
target. - write_
event_ log - Serialize a recorded event log (one entry per
on_eventinvocation) intotarget.