Module event

Module event 

This module contains the set of compiler-emitted event codes, and their explanations

Enums

Event
A typed wrapper around the raw trace events known to the compiler

Constants

FRAME_END_EVENT
This event indicates that a procedure call frame is exited
FRAME_START_EVENT
This event indicates that a procedure call frame is entered
PRINTLN_EVENT
This event indicates that a line should be printed.