pub struct DebuggerHost<S: SourceManager + ?Sized> { /* private fields */ }Expand description
This is an implementation of Host which is essentially miden_processor::DefaultHost, but extended with additional functionality for debugging, in particular it manages trace events that record the entry or exit of a procedure call frame.
Implementations
Sourceimpl<S> DebuggerHost<S>where
S: SourceManager + ?Sized,
impl<S> DebuggerHost<S>where
S: SourceManager + ?Sized,
Sourcepub fn new(source_manager: Arc<S>) -> Self
pub fn new(source_manager: Arc<S>) -> Self
Construct a new instance of DebuggerHost with the given source manager.
Sourcepub fn set_event_replay(&mut self, events: VecDeque<Vec<AdviceMutation>>)
pub fn set_event_replay(&mut self, events: VecDeque<Vec<AdviceMutation>>)
Set the event replay queue.
When non-empty, on_event() will pop mutations from this queue instead of
returning empty results. This is used for transaction debugging where events
were recorded during a prior execution.
Sourcepub fn register_trace_handler<F>(&mut self, event: TraceEvent, callback: F)
pub fn register_trace_handler<F>(&mut self, event: TraceEvent, callback: F)
Register a trace handler for event
Sourcepub fn register_assert_failed_tracer<F>(&mut self, callback: F)
pub fn register_assert_failed_tracer<F>(&mut self, callback: F)
Register a handler to be called when an assertion in the VM fails
Sourcepub fn handle_assert_failed(
&mut self,
clk: RowIndex,
err_code: Option<NonZeroU32>,
)
pub fn handle_assert_failed( &mut self, clk: RowIndex, err_code: Option<NonZeroU32>, )
Invoke the assert-failed handler, if registered.
This is called externally when step() returns an assertion error, since
on_assert_failed no longer exists on the Host trait in 0.21.
Sourcepub fn load_mast_forest(&mut self, forest: Arc<MastForest>)
pub fn load_mast_forest(&mut self, forest: Arc<MastForest>)
Load forest into the MAST store for this host
Sourcepub fn register_event_handler(
&mut self,
event: EventName,
handler: Arc<dyn EventHandler>,
) -> Result<(), ExecutionError>
pub fn register_event_handler( &mut self, event: EventName, handler: Arc<dyn EventHandler>, ) -> Result<(), ExecutionError>
Registers an event handler for use during program execution.