pub struct Executor { /* private fields */ }Expand description
The Executor is responsible for executing a program with the Miden VM.
It is used by either converting it into a DebugExecutor, and using that to manage execution step-by-step, such as is done by the debugger; or by running the program to completion and obtaining an ExecutionTrace, which can be used to introspect the final program state.
Implementations
Sourceimpl Executor
impl Executor
Sourcepub fn new(args: Vec<Felt>) -> Self
pub fn new(args: Vec<Felt>) -> Self
Construct an executor with the given arguments on the operand stack
Sourcepub fn from_config(config: ExecutionConfig) -> Self
pub fn from_config(config: ExecutionConfig) -> Self
Construct an executor from the given configuration
NOTE: The execution options for tracing/debugging will be set to true for you
pub fn with_registry(self, registry: HybridPackageRegistry) -> Self
Sourcepub fn with_advice_inputs(&mut self, advice: AdviceInputs) -> &mut Self
pub fn with_advice_inputs(&mut self, advice: AdviceInputs) -> &mut Self
Set the contents of memory for the shadow stack frame of the entrypoint
Sourcepub fn with_package(
&mut self,
package: Arc<Package>,
) -> Result<&mut Self, Report>
pub fn with_package( &mut self, package: Arc<Package>, ) -> Result<&mut Self, Report>
Add a Package to the execution context
Sourcepub fn with_event_advice_mutations_recording(&mut self) -> &mut Self
pub fn with_event_advice_mutations_recording(&mut self) -> &mut Self
Record the advice mutations produced by each event handler invocation during execution.
Recording is a private detail of the debug host created by Executor::into_debug: once the program completes, take the log via DebuggerHost::take_recorded_event_mutations on the DebugExecutor’s host, and feed it back into Executor::into_debug_with_replay to debug the same execution later without the original event handlers (e.g. transaction debugging with event replay).
Mutations are only recorded for live event handling; nothing is recorded while an event replay queue is being consumed.
Sourcepub fn register_event_handler(
&mut self,
event: EventName,
handler: Arc<dyn EventHandler>,
) -> Result<&mut Self, ExecutionError>
pub fn register_event_handler( &mut self, event: EventName, handler: Arc<dyn EventHandler>, ) -> Result<&mut Self, ExecutionError>
Register a VM event handler to be available during execution.
Sourcepub fn with_profiler_config(
&mut self,
profiler_config: ProfilerConfig,
) -> &mut Self
pub fn with_profiler_config( &mut self, profiler_config: ProfilerConfig, ) -> &mut Self
Set the profiler configuration for this executor.
Sourcepub fn into_debug(
self,
package: Arc<Package>,
source_manager: Arc<dyn SourceManager>,
) -> DebugExecutor
pub fn into_debug( self, package: Arc<Package>, source_manager: Arc<dyn SourceManager>, ) -> DebugExecutor
Convert this Executor into a DebugExecutor, which captures much more information about the program being executed, and must be stepped manually.
Sourcepub fn into_debug_with_replay(
self,
package: Arc<Package>,
source_manager: Arc<dyn SourceManager>,
extra_mast_forests: Vec<LoadedMastForest>,
event_replay: VecDeque<Vec<AdviceMutation>>,
) -> DebugExecutor
pub fn into_debug_with_replay( self, package: Arc<Package>, source_manager: Arc<dyn SourceManager>, extra_mast_forests: Vec<LoadedMastForest>, event_replay: VecDeque<Vec<AdviceMutation>>, ) -> DebugExecutor
Convert this Executor into a DebugExecutor with event replay support.
Like into_debug, but additionally:
- Loads
extra_forestsinto the host’s MAST forest store - Sets the event replay queue so that
on_event()returns pre-recorded mutations
This is used for transaction debugging where events were recorded during a prior execution with the real transaction host.
Sourcepub fn capture_trace(
self,
package: Arc<Package>,
source_manager: Arc<dyn SourceManager>,
) -> ExecutionTrace
pub fn capture_trace( self, package: Arc<Package>, source_manager: Arc<dyn SourceManager>, ) -> ExecutionTrace
Execute the given program until termination, producing a trace
Sourcepub fn execute(
self,
package: Arc<Package>,
source_manager: Arc<dyn SourceManager>,
) -> ExecutionTrace
pub fn execute( self, package: Arc<Package>, source_manager: Arc<dyn SourceManager>, ) -> ExecutionTrace
Execute the given program, producing a trace
Sourcepub fn execute_into<T>(
self,
package: Arc<Package>,
source_manager: Arc<dyn SourceManager>,
) -> Twhere
T: FromMidenRepr + PartialEq,
pub fn execute_into<T>(
self,
package: Arc<Package>,
source_manager: Arc<dyn SourceManager>,
) -> Twhere
T: FromMidenRepr + PartialEq,
Execute a program, parsing the operand stack outputs as a value of type T