DebugQuery

Trait DebugQuery 

pub trait DebugQuery {
    // Required methods
    fn state(&self) -> ProcessorState<'_>;
    fn current_context(&self) -> ContextId;
    fn current_clock(&self) -> RowIndex;

    // Provided methods
    fn read_memory_word(&self, addr: u32) -> Result<Option<Word>, MemoryError> { ... }
    fn read_memory_element(&self, addr: u32) -> Option<Felt> { ... }
    fn read_bytes_for_type(
        &self,
        addr: NativePtr,
        ty: &Type,
    ) -> Result<Vec<u8>, MemoryReadError> { ... }
    fn read_from_rust_memory<T>(&self, addr: u32) -> Option<T>
       where T: Any + FromMidenRepr { ... }
}

Required Methods

Provided Methods

fn read_memory_word(&self, addr: u32) -> Result<Option<Word>, MemoryError>

Read the word at the given Miden memory address

fn read_memory_element(&self, addr: u32) -> Option<Felt>

Read the element at the given Miden memory address

fn read_bytes_for_type( &self, addr: NativePtr, ty: &Type, ) -> Result<Vec<u8>, MemoryReadError>

Read a raw byte vector from addr, under ctx, at cycle clk, sufficient to hold a value of type ty

fn read_from_rust_memory<T>(&self, addr: u32) -> Option<T>
where T: Any + FromMidenRepr,

Read a value of the given type, given an address in Rust’s address space

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors