Module felt

Module felt 

Structs

Felt
Wrapper around miden_processor::Felt that implements useful traits that are not implemented for that type.

Traits

FromMidenRepr
ToMidenRepr

Functions

bytes_to_words
Convert a byte array to an equivalent vector of words
push_wasm_ty_to_operand_stack
Converts value to its corresponding Wasm ABI type and pushes it to the stack.