Module glob

Module glob 

This is a no-std-compatible implementation of shell glob matching against paths.

This is a simplified version of the globset crate that is defined as part of ripgrep, designed for single globs, with only the bare minimum features we need.

Structs

Candidate
A candidate path for matching.
Error
Represents an error that can occur when parsing a glob pattern.
Glob
Glob represents a successfully parsed shell glob pattern.
GlobBuilder
A builder for a pattern.
GlobMatcher
A matcher for a single pattern.

Enums

ErrorKind
The kind of error that can occur when parsing a glob pattern.