Module profiling

Module profiling 

Re-exports

pub use self::config::ProfilerCliArgs;
pub use self::instrument::instrument_from_name;
pub use self::config::ProfilerConfig;
pub use self::instrument::Instrument;
pub use self::instrument::InstrumentRegistration;
pub use self::instrument::OpHistogramGlobal;
pub use self::instrument::OpHistogramProc;
pub use self::instrument::OutputResult;
pub use self::instrument::OutputWriter;

Modules

config
instrument
Every distinct kind of profiling data collection is an Instrument implementation that lives in a submodule.

Structs

Profiler
Holds the loaded Instruments and dispatches event handlers to them.