Every distinct kind of profiling data collection is an Instrument implementation that
lives in a submodule.
Each instrument is uniquely identified by its Instrument::name.
Structs
- OpHistogram
Global - An
Instrumentto create global operation histograms. - OpHistogram
Proc - An
Instrumentto create per-procedure operation histograms.
Enums
Traits
- Instrument
- The functionality required for an instrument to be plugged in to
Profiler. - Instrument
Registration - Represents the information needed to construct an Instrument dynamically
- Output
Writer
Functions
- instrument_
from_ name - Get an instance of instrument
name, if one has been registered by that name.