pub struct OpHistogramGlobal { /* private fields */ }Expand description
An Instrument to create global operation histograms.
The global histogram aggregates across all procedures over the entire runtime.
At each cycle, it records the current operation and produces a histogram of executed operations
weighted by cycles per operation. If opX takes 4 cycles and was executed twice, its count
will be 8.