pub struct OpHistogramProc { /* private fields */ }Expand description
An Instrument to create per-procedure operation histograms.
At each cycle, it records the current operation into the histogram of the most recent live
procedure. Operations that cannot be attributed to a procedure are collected into a separate
histogram, reported under [UNKNOWN_PROCEDURE].
The report contains one section per procedure, sorted by the number of cycles spent in that procedure (highest first).