pub struct Profiler { /* private fields */ }Expand description
Holds the loaded Instruments and dispatches event handlers to them.
The default is a no-op Profiler.
Implementations
Sourceimpl Profiler
impl Profiler
pub fn from_config(config: ProfilerConfig) -> Self
Sourcepub fn on_operation_execution_cycle(&mut self, op: Operation)
pub fn on_operation_execution_cycle(&mut self, op: Operation)
Records the op with every active instrument, otherwise it’s a no-op.
Sourcepub fn write_reports(&self)
pub fn write_reports(&self)
Writes every instrument’s report to the configured reports output directory.
Failure to write a report should not abort execution, therefore this function always succeeds. If any errors occur they are logged.