pub struct HybridPackageRegistry { /* private fields */ }Expand description
The in-memory package registry used during debugger execution.
This is initialized per-session, or on an as-needed basis.
It can be constructed in various ways, but the recommended way to use it is
HybridPackageRegistry::new, which loads packages from the local filesystem registry (if
available), and adds in any libraries requested explicitly via -l.
Implementations
Sourceimpl HybridPackageRegistry
impl HybridPackageRegistry
Sourcepub fn new(
sysroot: Option<&Path>,
search_paths: &[PathBuf],
link_libraries: &[LinkLibrary],
) -> Result<Self, Report>
pub fn new( sysroot: Option<&Path>, search_paths: &[PathBuf], link_libraries: &[LinkLibrary], ) -> Result<Self, Report>
Get a new instance of the registry from compiled package inputs.
Sourcepub fn from_local_registry(sysroot: &Path) -> Result<Self, Report>
pub fn from_local_registry(sysroot: &Path) -> Result<Self, Report>
Get a new instance of the registry seeded with packages available in the local filesystem- based package store.
This returns an error if --sysroot was not provided/set.
pub fn all(&self) -> impl IntoIterator<Item = Arc<Package>>