Crate miden_debug_engine

Crate miden_debug_engine 

Re-exports

pub use self::felt::Felt;
pub use self::felt::FromMidenRepr;
pub use self::felt::ToMidenRepr;
pub use self::felt::bytes_to_words;
pub use self::felt::push_wasm_ty_to_operand_stack;
pub use miden_debug_types as debug_types;
pub use miden_processor as processor;
pub use self::debug::*;
pub use self::exec::*;

Modules

debug
events
exec
felt
profiling

Macros

register_instrument

Structs

HybridPackageRegistry
The in-memory package registry used by the compiler
LinkLibrary
A library requested by the user to be linked against during compilation

Functions

normalize_source_path
Converts a source URI or path into a stable form for loading and comparison.