Module debug

Module debug 

Structs

Breakpoint
CallFrame
CallStack
CurrentFrame
DebugVarSnapshot
A snapshot of a debug variable at a specific clock cycle.
DebugVarTracker
Tracks debug variable snapshots, mapping variable names to their most recent location info.
NativePtr
This represents a descriptor for a pointer translated from the IR into a form suitable for referencing data in Miden’s linear memory.
ReadMemoryExpr
ResolvedLocation
StackTrace
StepInfo

Enums

BreakpointType
ControlFlowOp
FormatType
MemoryMode
OpDetail

Functions

resolve_variable_value
Resolve a debug variable’s value given its location and the current VM state.