Module debug

Module debug 

Structs

Breakpoint
CallFrame
CallStack
CurrentFrame
NativePtr
This represents a descriptor for a pointer translated from the IR into a form suitable for referencing data in Miden’s linear memory.
ReadMemoryExpr
ResolvedLocation
StackTrace
StepInfo

Enums

BreakpointType
ControlFlowOp
FormatType
MemoryMode
OpDetail