Module exec

Module exec 

Re-exports

pub use self::event::Event;

Modules

event
This module contains the set of compiler-emitted event codes, and their explanations

Structs

DebugExecutor
A special version of crate::Executor which provides finer-grained control over execution, and captures a ton of information about the program being executed, so as to make it possible to introspect everything about the program and the state of the VM at a given cycle.
DebuggerHost
This is an implementation of Host which is essentially miden_processor::DefaultHost, but extended with additional functionality for debugging, in particular it manages trace events that record the entry or exit of a procedure call frame.
DiagnosticExecutor
A [ProgramExecutor] that wraps FastProcessor with diagnostic capabilities.
EventMutationRecorder
A shared, cloneable log of the advice mutations produced by event handlers.
ExecutionConfig
ExecutionTrace
An ExecutionTrace represents a final state of a program that was executed.
Executor
The Executor is responsible for executing a program with the Miden VM.
MastForestRecorder
A shared, cloneable log of the MAST forests a host resolved during execution.
ReplaySnapshot
Everything needed to replay a recorded execution in the debugger.
ReplaySnapshotRecorder
Shared status handle for a configured replay snapshot write.
ReplaySnapshotWrite
Successful replay snapshot write metadata.
ReplaySnapshotWriteError
Error metadata for a failed replay snapshot write.

Enums

ReplaySnapshotError
Error reading a ReplaySnapshot from a file.

Traits

DebugQuery

Functions

clone_advice_mutation
Clone a single AdviceMutation.
clone_advice_mutations
Clone a batch of AdviceMutations. See clone_advice_mutation.
read_advice_mutation
Deserialize a single AdviceMutation from source.
read_event_log
Deserialize a recorded event log from source.
write_advice_mutation
Serialize a single AdviceMutation into target.
write_event_log
Serialize a recorded event log (one entry per on_event invocation) into target.