Structs
- Debug
Executor - A special version of crate::Executor which provides finer-grained control over execution, and captures a ton of information about the program being executed, so as to make it possible to introspect everything about the program and the state of the VM at a given cycle.
- Debugger
Host - This is an implementation of Host which is essentially miden_processor::DefaultHost, but extended with additional functionality for debugging, in particular it manages trace events that record the entry or exit of a procedure call frame.
- Diagnostic
Executor - A
ProgramExecutorthat wrapsFastProcessorwith diagnostic capabilities. - Execution
Config - Execution
Trace - An ExecutionTrace represents a final state of a program that was executed.
- Executor
- The Executor is responsible for executing a program with the Miden VM.
- Trace
Monitor - Can be used with
DebugExecutor::step_untilto break on trace events
Enums
- Trace
Event - A typed wrapper around the raw trace events known to the compiler
Constants
- TRACE_
PRINT_ LN - This event is emitted via
trace, and indicates that a line should be printed.
Type Aliases
- Trace
Handler - A callback to be executed when a TraceEvent occurs