Module exec

Module exec 

Structs

DebugExecutor
A special version of crate::Executor which provides finer-grained control over execution, and captures a ton of information about the program being executed, so as to make it possible to introspect everything about the program and the state of the VM at a given cycle.
DebuggerHost
This is an implementation of Host which is essentially miden_processor::DefaultHost, but extended with additional functionality for debugging, in particular it manages trace events that record the entry or exit of a procedure call frame.
DiagnosticExecutor
A ProgramExecutor that wraps FastProcessor with diagnostic capabilities.
ExecutionConfig
ExecutionTrace
An ExecutionTrace represents a final state of a program that was executed.
Executor
The Executor is responsible for executing a program with the Miden VM.

Enums

TraceEvent
A typed wrapper around the raw trace events known to the compiler

Type Aliases

TraceHandler
A callback to be executed when a TraceEvent occurs at a given clock cycle