Module profiling

Module profiling 

Re-exports

pub use config::ProfilerCliArgs;
pub use config::ProfilerConfig;
pub use instrument::Instrument;
pub use instrument::InstrumentRegistration;
pub use instrument::OpHistogramGlobal;
pub use instrument::OpHistogramProc;
pub use instrument::instrument_from_name;

Modules

config
instrument
Every distinct kind of profiling data collection is an Instrument implementation that lives in a submodule.

Structs

Profiler
Holds the loaded Instruments and dispatches event handlers to them.