Module instrument

Module instrument 

Every distinct kind of profiling data collection is an Instrument implementation that lives in a submodule.

Each instrument is uniquely identified by its Instrument::name.

Structs

OpHistogram
An Instrument to create operation histograms.

Enums

InstrumentError

Traits

Instrument
The functionality required for an instrument to be plugged in to Profiler.
InstrumentRegistration
Represents the information needed to construct an Instrument dynamically

Functions

instrument_from_name
Get an instance of instrument name, if one has been registered by that name.